@@ -71,7 +71,7 @@ def dump(content, filename):
             json.dump(content, f, indent=4, cls=NumpyEncoder)
     elif filename.endswith('.yml') or filename.endswith('.yaml'): 
         with open(filename, 'w') as f:
-            yaml.safe_dump(content, f)
+            yaml.safe_dump(content, f, default_flow_style=False)
     elif filename.endswith('.txt') or filename.endswith('.md') or filename.endswith('.sh') or filename.endswith('.bash') or filename.endswith('.log'): 
         with open(filename, 'w') as f:
             f.write(content)
